@@ -3,7 +3,7 @@
 #  reconstituting series which should contain similar information. 
 
 # The object "TSdataconcentrate" is a TSdata object plus a reduction 
-#  (proj) estimated with est.projection.
+#  (proj) estimated with estProjection.
 
 
 ############################################################################
@@ -31,35 +31,33 @@
 #  for comparison (as in tfplot). The truely concentrated data is produced on
 #  demand by concentrateOnly.
 
-est.projection <- function(data, center=TRUE, scale=TRUE, ...) UseMethod("est.projection")
+estProjection <- function(data, center=TRUE, scale=TRUE, ...) UseMethod("estProjection")
 
-est.projection.default <- function(data, center=TRUE, scale=TRUE, n=1, ...)
+estProjection.default <- function(data, center=TRUE, scale=TRUE, n=1, ...)
  {#  (... further arguments, currently disregarded)
   # data should be a matrix. n is number of components to keep.
-  # prcomponents may be added to mva as prcomp or princomp??
-  prcomponents <- function(x, center=TRUE, scale=TRUE, N=nrow(x)-1)
+  # prcomponents is almost prcomp
+  prcomp <- function(x, retx = TRUE, center=TRUE, scale=TRUE, tol=sqrt(.Machine$double.eps))
    {if (center) center <- apply(x,2,mean)
     else        center <- rep(0, ncol(x))
     if (scale)  scale  <- sqrt(apply(x,2,var)) 
     else        scale  <- rep(1, ncol(x))
     s <- La.svd(sweep(sweep(as.matrix(x),2, center),2, scale, FUN="/"))
     # remove anything corresponding to effectively zero singular values.
-    rank <- sum(abs(s$d) > (abs(s$d[1])*sqrt(.Machine$double.eps)))  
-#   list(sdev=s$d/sqrt(N), proj=s$v,x=x %*% s$v, center=center, scale=scale)
-#   list(sdev=s$d/sqrt(N), proj=s$v, center=center, scale=scale)
-#  switched to La.svd
-    list(sdev=s$d/sqrt(N),
-         proj=Conj(t(s$vt[1:rank, , drop=FALSE])), 
-	 center=center, scale=scale)
+    rank <- sum(abs(s$d) > (abs(s$d[1])*tol))  
+    v <- Conj(t(s$vt[1:rank, , drop=FALSE]))
+    r <- list(sdev=s$d/sqrt(nrow(x)-1), rotation=v)
+    if (retx) r$x <- x %*% s$v
+    r
    }
   data <- freeze(data)
   if (ncol(data) < n) stop("n cannot exceed columns of data.")
-  conc<- prcomponents(data,center=center, scale=scale)
-  conc$proj <- conc$proj[,1:n, drop=FALSE]
-  classed(conc, "concentrator") # constructor
+  pr<- prcomp(data, retx = FALSE, center=center, scale=scale)
+  classed(list(sdev=pr$sdev,  proj=pr$rotation[,1:n, drop=FALSE],
+     center=center, scale=scale), "concentrator") # constructor
  }
 
-est.projection.TSdata <- function(data, center=TRUE, scale=TRUE, m=1,p=1, ...)
+estProjection.TSdata <- function(data, center=TRUE, scale=TRUE, m=1,p=1, ...)
  {#  (... further arguments, currently disregarded)
   # use principle components if there is just input or just output, otherwise
   # otherwise use canonical correlation.
@@ -86,7 +84,7 @@ est.projection.TSdata <- function(data, center=TRUE, scale=TRUE, m=1,p=1, ...)
   if ((0!= nseriesInput(data)) & (0!=nseriesOutput(data)))
     {if (nseriesInput(data) < m) stop("m cannot exceed input data dimension.")
      if (nseriesOutput(data)< p) stop("p cannot exceed output data dimension.")
-     cc <- cancorrelation(input.data(data), output.data(data),
+     cc <- cancorrelation(inputData(data), outputData(data),
                   xcenter=center, ycenter=center, xscale=scale, yscale=scale)
      conc$input$proj    <- cc$xcoef[ , 1:m, drop=FALSE] 
      conc$input$center  <- cc$xcenter
@@ -99,11 +97,11 @@ est.projection.TSdata <- function(data, center=TRUE, scale=TRUE, m=1,p=1, ...)
     }
   else if (0!= nseriesInput(data))
     {if (nseriesInput(data) < m) stop("m cannot exceed input data dimension.")
-     conc$input <- est.projection( input.data(data),center=center, scale=scale, n=m)
+     conc$input <- estProjection( inputData(data),center=center, scale=scale, n=m)
     }
   else if (0!=nseriesOutput(data))
     {if (nseriesOutput(data) < p) stop("p cannot exceed output data dimension.")
-     conc$output<- est.projection(output.data(data),center=center, scale=scale, n=p)
+     conc$output<- estProjection(outputData(data),center=center, scale=scale, n=p)
     }
   classed(conc, "TSdataconcentrator") # constructor
  }
@@ -114,10 +112,10 @@ concentrate <- function(d, conc=NULL, center=TRUE, scale=TRUE, ...)
 
 concentrate.default <- function(d, conc=NULL, center=TRUE, scale=TRUE, n=1, ...)
  {#  (... further arguments, currently disregarded)
-  #conc=est.projection(d, center=center, scale=scale, n=n)) misses freeze
-  # conc (projection) as returned by prcomp (see est.projection),
+  #conc=estProjection(d, center=center, scale=scale, n=n)) misses freeze
+  # conc (projection) as returned by prcomp (see estProjection),
   d <- freeze(d)
-  if (is.null(conc)) conc <- est.projection(d, center=center, scale=scale, n=n)
+  if (is.null(conc)) conc <- estProjection(d, center=center, scale=scale, n=n)
   else conc <- concentrator(conc)
   attr(d, "concentrator") <- conc
 #  attr(newd, "original") <- d
@@ -126,14 +124,14 @@ concentrate.default <- function(d, conc=NULL, center=TRUE, scale=TRUE, n=1, ...)
 
 concentrate.TSdata <- function(d, conc=NULL, center=TRUE, scale=TRUE, m=1, p=1, ...)
  {#  (... further arguments, currently disregarded)
-  #conc=est.projection(d, center=center, scale=scale, m=m, p=p)) misses freeze
+  #conc=estProjection(d, center=center, scale=scale, m=m, p=p)) misses freeze
   d <- freeze(d)
-  if (is.null(conc)) conc <- est.projection(d, center=center, scale=scale, m=m, p=p)
+  if (is.null(conc)) conc <- estProjection(d, center=center, scale=scale, m=m, p=p)
   else conc <- concentrator(conc)
   if (0!= nseriesInput(d))
-      input.data(d) <- concentrate(input.data(d), conc=conc$input)
+      inputData(d) <- concentrate(inputData(d), conc=conc$input)
   if (0!=nseriesOutput(d))
-     output.data(d) <- concentrate(output.data(d), conc=conc$output)
+     outputData(d) <- concentrate(outputData(d), conc=conc$output)
   classed(d, c("TSdataconcentrate", "TSdata")) # constructor (concentrate.TSdata)
  }
 
@@ -159,7 +157,7 @@ concentrateOnly.concentrate <- function(d)
   newd <-  sweep(sweep(d,2, conc$center), 2, conc$scale, FUN="/") %*% conc$proj
   tframe(newd) <- tframe(d) # newd will not (necessarily) have the class of d
 #  seriesNames(newd) <- paste("concentrate", seq(ncol(d)))
-  seriesNames(newd) <- concentrated.seriesNames(d)
+  seriesNames(newd) <- concentratedSeriesNames(d)
   attr(newd, "concentrator") <- conc
   attr(newd, "original") <- NULL
 #  classed(newd, dseclass(d)[-1])  # newd may not have correct structure for
@@ -266,12 +264,12 @@ reconstitute.concentrate <- function(d, conc=concentrator(d),
 reconstitute.TSdataconcentrate <- function(d, conc=concentrator(d),
                                     names=seriesNames(d))
  {# d as returned by concentrate. A different conc (proj) can be used.
-  # don't use input.data(d) or input.data(concentrateOnly(d)) here as they both
+  # don't use inputData(d) or inputData(concentrateOnly(d)) here as they both
   # obscure the fact that d is concentrate. ??but so what ? this comment may be old
   if (0!= nseriesInput(d))
-    input.data(d) <- reconstitute(d$input, conc$input, names=names$input) 
+    inputData(d) <- reconstitute(d$input, conc$input, names=names$input) 
   if (0!=nseriesOutput(d)) 
-   output.data(d) <- reconstitute(d$output, conc$output,names=names$output)
+   outputData(d) <- reconstitute(d$output, conc$output,names=names$output)
   classed(d, c("TSdatareconstitute", "TSdata"))# constructor reconstitute.TSdataconcentrate)
  }
 
@@ -294,18 +292,18 @@ canonical.prediction <- function(d, conc=concentrator(d),
      prj$v <- prj$v[q,  , drop=FALSE] 
      prj$d <- prj$d[q]
     }
-  pred <- reconstitute(input.data(concentrateOnly(d), series=q), prj,
+  pred <- reconstitute(inputData(concentrateOnly(d), series=q), prj,
                            names=seriesNamesOutput(concentrateOriginal(d)))
-  attr(pred, "original") <- output.data(concentrateOriginal(d))
-  classed(pred, "TScanonical.prediction") #constructor (canonical.prediction)
+  attr(pred, "original") <- outputData(concentrateOriginal(d))
+  classed(pred, "TScanonicalPrediction") #constructor (canonical.prediction)
  }
 
-is.TScanonical.prediction <- function(x) {inherits(x, "TScanonical.prediction")}
+is.TScanonicalPrediction <- function(x) {inherits(x, "TScanonicalPrediction")}
 
-concentrateOriginal.TScanonical.prediction <- function(d)
+concentrateOriginal.TScanonicalPrediction <- function(d)
     {attr(d, "original")}   
 
-tfplot.TScanonical.prediction <- function(x, start.=NULL, end.=NULL,
+tfplot.TScanonicalPrediction <- function(x, start.=NULL, end.=NULL,
 	 series=seq(nseries(x)),
 	 Title=NULL, xlab=NULL, ylab=NULL,
          graphs.per.page=5, mar=par()$mar, reset.screen=TRUE)
@@ -319,22 +317,22 @@ tfplot.TScanonical.prediction <- function(x, start.=NULL, end.=NULL,
 }
 
 	 	 
-start.TScanonical.prediction <- function(x, ...){start(concentrateOriginal(x), ...)}
+start.TScanonicalPrediction <- function(x, ...){start(concentrateOriginal(x), ...)}
 #  (... further arguments, currently disregarded)
-end.TScanonical.prediction <- function(x, ...){end(concentrateOriginal(x), ...)}
+end.TScanonicalPrediction <- function(x, ...){end(concentrateOriginal(x), ...)}
 #  (... further arguments, currently disregarded)
-periods.TScanonical.prediction <- function(x){periods(concentrateOriginal(x))}
-frequency.TScanonical.prediction <- function(x, ...){frequency(concentrateOriginal(x), ...)}
+periods.TScanonicalPrediction <- function(x){periods(concentrateOriginal(x))}
+frequency.TScanonicalPrediction <- function(x, ...){frequency(concentrateOriginal(x), ...)}
 #  (... further arguments, currently disregarded)
 
 
-percent.change.TScanonical.prediction <-function (obj, base=NULL, lag=1,
+percentChange.TScanonicalPrediction <-function (obj, base=NULL, lag=1,
     cumulate=FALSE, e=FALSE) {
-	pchange <- percent.change(classed(obj, dseclass(obj)[-1]),
+	pchange <- percentChange(classed(obj, dseclass(obj)[-1]),
 	    base=base, lag=lag, cumulate=cumulate, e=e)
-	attr(pchange, "original") <- percent.change(attr(obj, "original"),
+	attr(pchange, "original") <- percentChange(attr(obj, "original"),
 	    base=base, lag=lag, cumulate=cumulate, e=e)
-	classed(pchange, "TScanonical.prediction") #re constructor (percent.change)
+	classed(pchange, "TScanonicalPrediction") #re constructor (percentChange)
 }
   
 
@@ -345,21 +343,21 @@ percent.change.TScanonical.prediction <-function (obj, base=NULL, lag=1,
 ######################################################################
 
 
-est.concentratedModel <- function(data, estimation="est.VARX.ls",
+estConcentratedModel <- function(data, estimation="estVARXls",
                                          estimation.args=NULL, ...)
-     UseMethod("est.concentratedModel")
+     UseMethod("estConcentratedModel")
 
-est.concentratedModel.TSdata <- function(data, estimation="est.VARX.ls",  
+estConcentratedModel.TSdata <- function(data, estimation="estVARXls",  
               estimation.args=NULL, m=1, p=1, center=TRUE, scale=TRUE, ...) 
   {#  (... further arguments, currently disregarded)
-   d <- concentrate(data, conc=est.projection(data, m=m, p=p,
+   d <- concentrate(data, conc=estProjection(data, m=m, p=p,
                                         center=center, scale=scale))
-   est.concentratedModel(d, estimation=estimation, 
+   estConcentratedModel(d, estimation=estimation, 
                              estimation.args=estimation.args)
   }
 
-est.concentratedModel.TSdataconcentrate <- function(data, 
-     estimation="est.VARX.ls", 
+estConcentratedModel.TSdataconcentrate <- function(data, 
+     estimation="estVARXls", 
      estimation.args=NULL, warn=TRUE, ...) 
   {#  (... further arguments, currently disregarded)
    d <- concentrateOnly(data)
@@ -374,7 +372,7 @@ est.concentratedModel.TSdataconcentrate <- function(data,
 
 is.TSmodelconcentrate <- function(x) {inherits(x, "TSmodelconcentrate")}
 
-l.TSmodelconcentrate <- function(model,data, sampleT=nrow(output.data(data)), 
+l.TSmodelconcentrate <- function(model,data, sampleT=nrow(outputData(data)), 
                                   predictT=sampleT, result=NULL, warn=TRUE)
   {#model should be TSmodelconcentrate and data should be TSdataconcentrate
    if (!is.TSdataconcentrate(data)) stop("data should be TSdataconcentrate.")
@@ -385,7 +383,7 @@ l.TSmodelconcentrate <- function(model,data, sampleT=nrow(output.data(data)),
         names=seriesNamesOutput(data))
 
    if((!is.null(result)) && (result == "pred")) return(pred)
-   r <- residual.stats(pred, output.data(concentrateOriginal(data)),
+   r <- residualStats(pred, outputData(concentrateOriginal(data)),
                        sampleT=sampleT, warn=warn)
    if(is.null(result)) 
        return(classed(list(estimates = r, data = data, 
@@ -396,9 +394,9 @@ l.TSmodelconcentrate <- function(model,data, sampleT=nrow(output.data(data)),
   }
   
 
-check.consistent.dimensions.TSmodelconcentrate <- function(obj1, obj2=NULL)
+checkConsistentDimensions.TSmodelconcentrate <- function(obj1, obj2=NULL)
   {m <- classed(obj1, dseclass(obj1)[-1]) # deconstructor 
-   check.consistent.dimensions(m)
+   checkConsistentDimensions(m)
    if(!is.null(obj2))
        {if(nseriesOutput(obj1) != nseriesOutput(obj2))
 	    stop("Model and data output dimensions do not correspond.")
@@ -426,31 +424,31 @@ nseriesOutput.TSmodelconcentrate <- function(x)
 
 
 
-concentrated.dimension <- function(x){UseMethod("concentrated.dimension")}
+concentratedDimension <- function(x){UseMethod("concentratedDimension")}
    
-concentrated.dimension.concentrate <- function(x) {ncol(concentrator(x)$proj)}
+concentratedDimension.concentrate <- function(x) {ncol(concentrator(x)$proj)}
 
 
 
-concentrated.nseriesInput <- function(x) {concentrated.dimension(x$input)}
-concentrated.nseriesOutput <- function(x) {concentrated.dimension(x$output)}
+concentrated.nseriesInput <- function(x) {concentratedDimension(x$input)}
+concentrated.nseriesOutput <- function(x) {concentratedDimension(x$output)}
 
 
 
-concentrated.seriesNames <- function(x){UseMethod("concentrated.seriesNames")}
+concentratedSeriesNames <- function(x){UseMethod("concentratedSeriesNames")}
    
-concentrated.seriesNames.concentrate <- function(x)
-  { paste("concentrate", seq(concentrated.dimension(x))) }
+concentratedSeriesNames.concentrate <- function(x)
+  { paste("concentrate", seq(concentratedDimension(x))) }
 
-concentrated.seriesNames.TSdata <- function(x)
-   {list(input = concentrated.seriesNamesInput(x),
-        output = concentrated.seriesNamesOutput(x)) }
+concentratedSeriesNames.TSdata <- function(x)
+   {list(input = concentratedSeriesNamesInput(x),
+        output = concentratedSeriesNamesOutput(x)) }
 
-concentrated.seriesNamesInput <- function(x)
- {if(is.null(x$input)) NULL else concentrated.seriesNames(x$input)}
+concentratedSeriesNamesInput <- function(x)
+ {if(is.null(x$input)) NULL else concentratedSeriesNames(x$input)}
 
-concentrated.seriesNamesOutput <- function(x)
- {if(is.null(x$output)) NULL else concentrated.seriesNames(x$output)}
+concentratedSeriesNamesOutput <- function(x)
+ {if(is.null(x$output)) NULL else concentratedSeriesNames(x$output)}
 
 
 "tframe<-.concentrate" <- function(x, value){
@@ -491,11 +489,11 @@ tfwindow.concentrate <- function(x, ...)
  }
 
 
-select.series.concentrate <-function (x, series = seq(nrow(concentrator(x)$proj))) 
+selectSeries.concentrate <-function (x, series = seq(nrow(concentrator(x)$proj))) 
  {conc <- concentrator(x)
   cls <- dseclass(x)
-  orig <- select.series(concentrateOriginal(x), series=series)
-  # look at select.series.default to get series right
+  orig <- selectSeries(concentrateOriginal(x), series=series)
+  # look at selectSeries.default to get series right
   conc$sdev <- conc$sdev[series]
   conc$proj <- conc$proj[series,,drop=FALSE]
   conc$center <- conc$center[series]
@@ -547,34 +545,34 @@ tfplot.TSdatareconstitute <- function(x, ...)
 plot2by2 <- function(data, ...) {UseMethod("plot2by2")}
 
 plot2by2.TSdata <- function(data, ...)
-  {if (0==nseriesInput(data)) plot2by2(output.data(data))
-   else  plot2by2(tbind(input.data(data), output.data(data)))
+  {if (0==nseriesInput(data)) plot2by2(outputData(data))
+   else  plot2by2(tbind(inputData(data), outputData(data)))
   }
 
 plot2by2.default <- function(data, pch=".", ...)
 {  p <- ncol(data)
-   old.par <- par(mfrow = c(p, p), mar = c(2.1, 4.1, 3.1, 0.1))
+   old.par <- par(mfrow = c(p, p), mar = c(2.1, 4.1, 3.1, 0.1), no.readonly=TRUE)
    on.exit(par(old.par))
    for (i in 1:p) 
      for (j in 1:p)  tfplot(data[,i], data[,j], pch=pch, ...)
    invisible()
 }
 
-check.residuals.TSdataconcentrate <- function (data, ...) 
+checkResiduals.TSdataconcentrate <- function (data, ...) 
    {warning("This residual is the difference between original and reconstituted data")
-    invisible(check.residuals.TSdata(
-      TSdata(output=output.data(reconstitute(data)) - 
-                    output.data(concentrateOriginal(data))), ...))
+    invisible(checkResiduals.TSdata(
+      TSdata(output=outputData(reconstitute(data)) - 
+                    outputData(concentrateOriginal(data))), ...))
    }
     
-check.residuals.TSdatareconstitute <- function (data, ...) 
-   {invisible(check.residuals.TSdata(as.TSdata(data), ...)) }
+checkResiduals.TSdatareconstitute <- function (data, ...) 
+   {invisible(checkResiduals.TSdata(as.TSdata(data), ...)) }
 
 
-check.residuals.concentrated <- function (data, ...) 
-        {stop("defunct. Use concentrated.check.residuals")}
+checkResiduals.concentrated <- function (data, ...) 
+        {stop("defunct. Use concentrated.checkResiduals")}
 
-concentrated.check.residuals <- function (data, ...) 
-        {check.residuals(concentrateOnly(data), ...)}
+concentrated.checkResiduals <- function (data, ...) 
+        {checkResiduals(concentrateOnly(data), ...)}
 
 
